@@ -47,9 +47,9 @@ class MethodNameWgt(qt.QWidget):
 
         self.meth_name = qt.QLabel('Method Name', self)
         #        self.meth_name.setAlignment(qt.Qt.AlignLeft)
-        self.meth_name.setStyleSheet("font-size: 16px;"
+        self.meth_name.setStyleSheet("font-size: {}px;"
                                      "font: bold;"
-                                     "color: white;");
+                                     "color: white;".format(int(dpivalue(16))));
 
         #                                  "background-color: rgb(220,220,220);}"
         self.button_hover_style = "QPushButton:hover {" \
@@ -62,7 +62,7 @@ class MethodNameWgt(qt.QWidget):
 
         self.hlayout.addWidget(self.meth_name)
         self.setLayout(self.hlayout)
-        self.setFixedHeight(40)
+        self.setFixedHeight(dpivalue(40))
         self.hide()
         self.button_widget = None
 
